@@ -1,6 +1,6 @@
 /* datain.c
  * Reads in survey files, dealing with special characters, keywords & data
- * Copyright (C) 1991-2003,2005,2009,2010,2011,2012,2013,2014,2015,2016 Olly Betts
+ * Copyright (C) 1991-2003,2005,2009,2010,2011,2012,2013,2014,2015,2016,2017 Olly Betts
  * Copyright (C) 2004 Simeon Warner
  *
  * This program is free software; you can redistribute it and/or modify
@@ -129,8 +129,9 @@ show_line(int col, int width)
 
    /* Read the whole line and write it out. */
    PUTC(' ', STDERR);
-   while (!feof(file.fh)) {
+   while (1) {
       int c = GETC(file.fh);
+      /* Note: isEol() is true for EOF */
       if (isEol(c)) break;
       if (c == '\t') ++tabs;
       PUTC(c, STDERR);
@@ -519,6 +520,16 @@ data_file(const char *pth, const char *fnm)
       file.lpos = 0;
       file.reported_where = fFalse;
       nextch();
+      if (fmt == FMT_SVX && ch == 0xef) {
+	 /* Maybe a UTF-8 "BOM" - skip if so. */
+	 if (nextch() == 0xbb && nextch() == 0xbf) {
+	    nextch();
+	    file.lpos = 3;
+	 } else {
+	    rewind(fh);
+	    ch = 0xef;
+	 }
+      }
    }
 
    using_data_file(file.filename);
@@ -601,13 +612,13 @@ data_file(const char *pth, const char *fnm)
 #endif
 
    if (fmt == FMT_DAT) {
-      while (!feof(file.fh) && !ferror(file.fh)) {
-	 static reading compass_order[] = {
+      while (ch != EOF && !ferror(file.fh)) {
+	 static const reading compass_order[] = {
 	    Fr, To, Tape, CompassDATComp, CompassDATClino,
 	    CompassDATLeft, CompassDATRight, CompassDATUp, CompassDATDown,
 	    CompassDATFlags, IgnoreAll
 	 };
-	 static reading compass_order_backsights[] = {
+	 static const reading compass_order_backsights[] = {
 	    Fr, To, Tape, CompassDATComp, CompassDATClino,
 	    CompassDATLeft, CompassDATRight, CompassDATUp, CompassDATDown,
 	    CompassDATBackComp, CompassDATBackClino,
@@ -653,7 +664,6 @@ data_file(const char *pth, const char *fnm)
 	 skipline();
 	 process_eol();
 	 /* <Survey team> */
-	 nextch();
 	 skipline();
 	 process_eol();
 	 /* DECLINATION: 1.00  FORMAT: DDDDLUDRADLN  CORRECTIONS: 2.00 3.00 4.00 */
@@ -694,7 +704,7 @@ data_file(const char *pth, const char *fnm)
 	 /* BLANK LINE */
 	 skipline();
 	 process_eol();
-	 while (!feof(file.fh)) {
+	 while (ch != EOF) {
 	    if (ch == '\x0c') {
 	       nextch();
 	       process_eol();
@@ -713,7 +723,7 @@ data_file(const char *pth, const char *fnm)
       }
    } else if (fmt == FMT_MAK) {
       nextch_handling_eol();
-      while (!feof(file.fh) && !ferror(file.fh)) {
+      while (ch != EOF && !ferror(file.fh)) {
 	 if (ch == '#') {
 	    /* include a file */
 	    int ch_store;
@@ -798,7 +808,7 @@ data_file(const char *pth, const char *fnm)
 	 pcs = pcsParent;
       }
    } else {
-      while (!feof(file.fh) && !ferror(file.fh)) {
+      while (ch != EOF && !ferror(file.fh)) {
 	 if (!process_non_data_line()) {
 	    f_export_ok = fFalse;
 	    switch (pcs->style) {
@@ -868,7 +878,7 @@ handle_plumb(clino_type *p_ctype)
    typedef enum {
       CLINO_NULL=-1, CLINO_UP, CLINO_DOWN, CLINO_LEVEL
    } clino_tok;
-   static sztok clino_tab[] = {
+   static const sztok clino_tab[] = {
       {"D",     CLINO_DOWN},
       {"DOWN",  CLINO_DOWN},
       {"H",     CLINO_LEVEL},
@@ -877,7 +887,7 @@ handle_plumb(clino_type *p_ctype)
       {"UP",    CLINO_UP},
       {NULL,    CLINO_NULL}
    };
-   static real clinos[] = {(real)M_PI_2, (real)(-M_PI_2), (real)0.0};
+   static const real clinos[] = {(real)M_PI_2, (real)(-M_PI_2), (real)0.0};
    clino_tok tok;
 
    skipblanks();
@@ -1421,7 +1431,7 @@ data_cartesian(void)
 
    reading first_stn = End;
 
-   reading *ordering;
+   const reading *ordering;
 
    again:
 
@@ -1560,7 +1570,7 @@ data_normal(void)
    bool fDepthChange;
    unsigned long compass_dat_flags = 0;
 
-   reading *ordering;
+   const reading *ordering;
 
    VAL(Tape) = VAL(BackTape) = HUGE_REAL;
    VAL(Comp) = VAL(BackComp) = HUGE_REAL;
@@ -1602,7 +1612,7 @@ data_normal(void)
 	  typedef enum {
 	     DIR_NULL=-1, DIR_FORE, DIR_BACK
 	  } dir_tok;
-	  static sztok dir_tab[] = {
+	  static const sztok dir_tab[] = {
 	     {"B",     DIR_BACK},
 	     {"F",     DIR_FORE},
 	  };
@@ -1998,7 +2008,7 @@ static void
 data_passage(void)
 {
    prefix *stn = NULL;
-   reading *ordering;
+   const reading *ordering;
 
    for (ordering = pcs->ordering ; ; ordering++) {
       skipblanks();
@@ -2069,7 +2079,7 @@ data_nosurvey(void)
 
    reading first_stn = End;
 
-   reading *ordering;
+   const reading *ordering;
 
    again:
 
