@@ -4,7 +4,7 @@
 //  OpenGL implementation for the GLA abstraction layer.
 //
 //  Copyright (C) 2002-2003,2005 Mark R. Shinwell
-//  Copyright (C) 2003,2004,2005,2006,2007,2010,2011,2012,2013,2014,2015 Olly Betts
+//  Copyright (C) 2003,2004,2005,2006,2007,2010,2011,2012,2013,2014,2015,2017 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -426,7 +426,7 @@ void GLACanvas::FirstShow()
 	    // we cached hints for, so use those hints.
 	    int v;
 	    if (cfg->Read(wxT("blob_method"), &v, 0) &&
-		(v == POINT || v == LINES)) {
+		(v == SPRITE || v == POINT || v == LINES)) {
 		// How to draw blobs.
 		blob_method = v;
 	    }
@@ -1159,7 +1159,7 @@ void GLACanvas::PlaceVertex(glaCoord x, glaCoord y, glaCoord z,
 #ifdef GLA_DEBUG
     m_Vertices++;
 #endif
-    glTexCoord2i(tex_x, tex_y);
+    glTexCoord2f(tex_x, tex_y);
     glVertex3d(x, y, z);
 }
 
@@ -1306,6 +1306,10 @@ void GLACanvas::BeginCrosses()
 	glPushAttrib(GL_TRANSFORM_BIT|GL_VIEWPORT_BIT|GL_ENABLE_BIT);
 	CHECK_GL_ERROR("BeginCrosses", "glPushAttrib 2");
 	SetIndicatorTransform();
+	// Align line drawing to pixel centres to get pixel-perfect rendering
+	// (graphics card and driver bugs aside).
+	glTranslated(-0.5, -0.5, 0);
+	CHECK_GL_ERROR("BeginCrosses", "glTranslated");
 	glEnable(GL_DEPTH_TEST);
 	CHECK_GL_ERROR("BeginCrosses", "glEnable GL_DEPTH_TEST");
 	glBegin(GL_LINES);
@@ -1343,10 +1347,12 @@ void GLACanvas::DrawCross(glaCoord x, glaCoord y, glaCoord z)
 	// cross arms to avoid uneven crosses.
 	X = rint(X);
 	Y = rint(Y);
+	// Need to extend lines by an extra pixel (which shouldn't get drawn by
+	// the diamond-exit rule).
 	PlaceVertex(X - 3, Y - 3, Z);
-	PlaceVertex(X + 3, Y + 3, Z);
+	PlaceVertex(X + 4, Y + 4, Z);
 	PlaceVertex(X - 3, Y + 3, Z);
-	PlaceVertex(X + 3, Y - 3, Z);
+	PlaceVertex(X + 4, Y - 4, Z);
     }
 #ifdef GLA_DEBUG
     m_Vertices++;
