@@ -265,6 +265,8 @@ static wxString scales[] = {
     wxT("100000")
 };
 
+// The order of these arrays must match export_format in export.h.
+
 static wxString formats[] = {
     wxT("DXF"),
     wxT("EPS"),
@@ -729,10 +731,18 @@ svxPrintDlg::OnExport(wxCommandEvent&) {
 
 	try {
 	    const wxString& export_fnm = dlg.GetPath();
+	    unsigned mask = format_info[format_idx];
+	    double rot, tilt;
+	    if (mask & EXPORT_3D) {
+		rot = 0.0;
+		tilt = -90.0;
+	    } else {
+		rot = m_layout.rot;
+		tilt = m_layout.tilt;
+	    }
 	    if (!Export(export_fnm, m_layout.title,
 			m_layout.datestamp, m_layout.datestamp_numeric, mainfrm,
-			m_layout.rot, m_layout.tilt,
-			m_layout.get_effective_show_mask(),
+			rot, tilt, m_layout.get_effective_show_mask(),
 			export_format(format_idx), input_projection.utf8_str(),
 			grid, text_height, marker_size, m_layout.Scale)) {
 		wxString m = wxString::Format(wmsg(/*Couldn’t write file “%s”*/402).c_str(),
@@ -1733,7 +1743,7 @@ svxPrintout::OnBeginPrinting() {
     pen_cross = new wxPen(colour_cross);
     pen_leg = new wxPen(colour_leg);
     pen_surface_leg = new wxPen(colour_surface_leg);
-    pen_splay = new wxPen(wxColour(192, 192, 192));
+    pen_splay = new wxPen(wxColour(128, 128, 128));
 
     m_layout->scX = 1;
     m_layout->scY = 1;
